@@ -3,14 +3,20 @@
 
 import unittest
 import contextlib
+import base64
 
+import gi
 from gi.repository import GLib
 
 try:
+    try:
+        gi.require_version("Gtk", "3.0")
+    except ValueError as e:
+        raise ImportError(e)
+    from gi.repository import Gtk
     from gi.repository import Pango
     from gi.repository import Atk
     from gi.repository import Gdk
-    from gi.repository import Gtk
     (Atk, Gtk, Pango)  # pyflakes
 
     import pygtkcompat
@@ -143,9 +149,17 @@ class TestGTKCompat(unittest.TestCase):
         gtk.gdk.Pixbuf()
 
     def test_pixbuf_loader(self):
+        # load a 1x1 pixel PNG from memory
+        data = base64.b64decode('iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAADUlEQVR42mP4n8Dw'
+                                'HwAGIAJf85Z3XgAAAABJRU5ErkJggg==')
         loader = gtk.gdk.PixbufLoader('png')
+        loader.write(data)
         loader.close()
 
+        pixbuf = loader.get_pixbuf()
+        self.assertEqual(pixbuf.get_width(), 1)
+        self.assertEqual(pixbuf.get_height(), 1)
+
     def test_pixbuf_formats(self):
         formats = gtk.gdk.pixbuf_get_formats()
         self.assertEqual(type(formats[0]), dict)
