@@ -1,6 +1,7 @@
 # -*- Mode: Python; py-indent-offset: 4 -*-
 # vim: tabstop=4 shiftwidth=4 expandtab
 
+import gc
 import unittest
 
 import gi
@@ -61,6 +62,12 @@ class TestGVariant(unittest.TestCase):
         self.assertEqual(variant.get_type_string(), '((si)(ub))')
         self.assertEqual(variant.unpack(), (('hello', -1), (_long(42), True)))
 
+    def test_new_tuple_sink(self):
+        # https://bugzilla.gnome.org/show_bug.cgi?id=735166
+        variant = GLib.Variant.new_tuple(GLib.Variant.new_tuple())
+        del variant
+        gc.collect()
+
     def test_create_dictionary(self):
         variant = GLib.Variant('a{si}', {})
         self.assertTrue(isinstance(variant, GLib.Variant))
@@ -487,3 +494,10 @@ class TestGVariant(unittest.TestCase):
         # with override constructor
         v = GLib.Variant('(is)', (1, 'somestring'))
         self.assertEqual(str(v), "(1, 'somestring')")
+
+
+class TestConstants(unittest.TestCase):
+
+    def test_basic_types_limits(self):
+        self.assertTrue(isinstance(GLib.MINFLOAT, float))
+        self.assertTrue(isinstance(GLib.MAXLONG, (int, _long)))
